==> bug2.37.tgz: look.c <==
#include <curses.h>
#include "bug2.h"

int look(int search)
{
	struct bug *eaten;
	char temp;
	int leftw = 0, rightw = 0, forwardw = 0;
	
	// look for mate and/or food
	
	temp = peek(1,0);
	if((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))
	{
		mate();
		// exausted ...
		return WAIT;
	} 
	
	if(temp == bugs->food_type)
	{
		if(bugs->race == PREDITOR)
		{
			switch(bugs->vector)
			{
				case 0:
					// screen up
					eaten = findbug((bugs->ypos - 1 + LINES-1) % (LINES-1),bugs->xpos);
					break;
				case 1:
					// screen right
					eaten = findbug(bugs->ypos,(bugs->xpos + 1) % COLS);
					break;
				case 2:
					// screen down
					eaten = findbug((bugs->ypos + 1) % (LINES-1),bugs->xpos);
					break;
				case 3: 
					// screen left
					eaten = findbug(bugs->ypos,(bugs->xpos - 1 + COLS) % COLS);
					break;                                          
				default:
					fprintf(stderr, "default in perditor eat bugs->vector is bad\n");
					break;
			}
			if(DEBUG)
				fprintf(stderr,"biten\n");
			eaten->food -= BITE_SIZE;
			if(eaten->food <= 0)
			{
				bugs->food += BUG_FOOD;
				die(eaten);
			}
			return WAIT;
		}
		else
		{
			placefood();  
			bugs->food++;
			return FORWARD;
		}
	}
	
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw--;

	// listen in back for preditor ...
	temp = peek(-1,0);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN * 2;
	temp = peek(-2,0);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	temp = peek(-1,1);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	temp = peek(-1,-1);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	// end listen ...

	temp = peek(1,0);
	if(temp == SPACE)
	{       
		temp = peek(2,0);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;

		if(temp == SPACE)
		{       
			temp = peek(3,0);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

			temp = peek(2,-1);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

			temp = peek(2,1);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

		}
		
		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;

		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;
	}
			
	temp = peek(0,-1);
	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
		leftw++;
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		leftw--;

	if(temp == SPACE)
	{
		temp = peek(0,-2);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			leftw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			leftw--;
	
		if(temp == SPACE)
		{
			temp = peek(0,-3);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				leftw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				leftw--;
	
			temp = peek(1,-2);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				leftw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				leftw--;
		}

		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			leftw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			leftw--;
	}
	
	temp = peek(0,1);
	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
		rightw++;
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		rightw--;

	if(temp == SPACE)
	{
		temp = peek(0,2);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			rightw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			rightw--;

		if(temp == SPACE)
		{
			temp = peek(0,3);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				rightw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				rightw--;

			temp = peek(1,2);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				rightw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				rightw--;
		}

		temp = peek(1,1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			rightw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			rightw--;
	}
	
	temp = peek(1,0);

	if((leftw)||(rightw)||(forwardw))	
	{
		// forward > left & right
		if((forwardw > leftw)&&(forwardw > rightw))
	        	if((forwardw > 0)&&(temp == SPACE))
        	        	return FORWARD;
	                else 
        	        	if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
        				return bugs->search[search];
        	        	else
	        	        	return getrandom(LEFT,RIGHT);

		// left > forward & right
		if((leftw > rightw)&&(leftw > forwardw))
	        	if(leftw > 0)
        	        	return LEFT;
	                else if(temp == SPACE)
        	        	if((bugs->search[search] == RIGHT)||(bugs->search[search] == FORWARD))
        	        		return bugs->search[search];
				else
	        	        	return getrandom(RIGHT, FORWARD);
			else
				return RIGHT;

		// right > left & forward
		if((rightw > leftw)&&(rightw > forwardw))
	        	if(rightw > 0)
        	        	return RIGHT;
			else if (temp == SPACE)
				if((bugs->search[search] == LEFT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return (getrandom(0,1) ? LEFT : FORWARD);
			else 
				return LEFT;
			
		// left & right > forward
		if((leftw == rightw)&&(rightw > forwardw))
	        	if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
	        		return bugs->search[search];
	        	else
	        		return getrandom(LEFT,RIGHT);

		// forward & right > left
		if((forwardw == rightw)&&(rightw > leftw))
                	if(temp == SPACE)
				if((bugs->search[search] == RIGHT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return getrandom(RIGHT,FORWARD);
			else
				return RIGHT;
			
		// forward & left > right
		if((forwardw == leftw)&&(leftw > rightw))
                	if(temp == SPACE)
				if((bugs->search[search] == LEFT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return (getrandom(0,1) ? LEFT : FORWARD);
			else
				return LEFT;

		// all equil
        	if(temp == SPACE)
        		if(bugs->search[search] == WAIT)
        			return getrandom(LEFT, FORWARD);
        		else
        			return bugs->search[search];
		else
			if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
				return bugs->search[search];
			else
				return getrandom(LEFT, RIGHT);
	}

	// default din't see anything good ...
	if((temp != SPACE)&&(bugs->search[search] == FORWARD))
		return getrandom(WAIT, RIGHT);

	return bugs->search[search];
}

char peek(int fw, int lr)
{
	int val;
	char temp[3];
	
	switch(bugs->vector)
	{
		case 0:
			move((bugs->ypos + LINES-1 - fw) % (LINES-1),(bugs->xpos + COLS + lr) % COLS);
			break;
		case 1:
			move((bugs->ypos + LINES-1 + lr) % (LINES-1),(bugs->xpos + COLS + fw) % COLS);
			break;
		case 2:
			move((bugs->ypos + LINES-1 + fw) % (LINES-1),(bugs->xpos + COLS - lr) % COLS);
			break;
		case 3:
			move((bugs->ypos + LINES-1 - lr) % (LINES-1),(bugs->xpos + COLS - fw) % COLS);
			break;
		default:
			fprintf(stderr,"default in peek bugs->vector is bad\n");
			break;   
	}
	val = innstr(temp,1);
	return temp[0];
}

==> bug2.103.tgz: look.c <==
#include <curses.h>
#include "bug2.h"

int look(int search)
{
	struct bug *eaten;
	char temp;
	int leftw = 0, rightw = 0, forwardw = 0;
	
	// look for mate and/or food
	
	temp = peek(1,0);
	if((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))
	{
		mate();
		// exausted ...
		return WAIT;
	} 
	
	if(temp == bugs->food_type)
	{
		if(bugs->race == PREDITOR)
		{
			switch(bugs->vector)
			{
				case 0:
					// screen up
					eaten = findbug((bugs->ypos - 1 + world_row) % world_row,bugs->xpos);
					break;
				case 1:
					// screen right
					eaten = findbug(bugs->ypos,(bugs->xpos + 1) % world_col);
					break;
				case 2:
					// screen down
					eaten = findbug((bugs->ypos + 1) % world_row,bugs->xpos);
					break;
				case 3: 
					// screen left
					eaten = findbug(bugs->ypos,(bugs->xpos - 1 + world_col) % world_col);
					break;                                          
				default:
					fprintf(stderr, "default in perditor eat bugs->vector is bad\n");
					break;
			}
			if(DEBUG)
				fprintf(stderr,"biten\n");
			eaten->food -= BITE_SIZE;
			if(eaten->food <= 0)
			{
				bugs->food += BUG_FOOD;
				die(eaten);
			}
			return WAIT;
		}
		else
		{
			placefood();  
			bugs->food++;
			return FORWARD;
		}
	}
	
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw--;

	// listen in back for preditor ...
	temp = peek(-1,0);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN * 2;
	temp = peek(-2,0);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	temp = peek(-1,1);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	temp = peek(-1,-1);
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		forwardw += RUN;
	// end listen ...

	temp = peek(1,0);
	if(temp == SPACE)
	{       
		temp = peek(2,0);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;

		if(temp == SPACE)
		{       
			temp = peek(3,0);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

			temp = peek(2,-1);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

			temp = peek(2,1);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				forwardw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				forwardw--;

		}
		
		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;

		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			forwardw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			forwardw--;
	}
			
	temp = peek(0,-1);
	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
		leftw++;
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		leftw--;

	if(temp == SPACE)
	{
		temp = peek(0,-2);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			leftw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			leftw--;
	
		if(temp == SPACE)
		{
			temp = peek(0,-3);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				leftw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				leftw--;
	
			temp = peek(1,-2);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				leftw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				leftw--;
		}

		temp = peek(1,-1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			leftw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			leftw--;
	}
	
	temp = peek(0,1);
	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
		rightw++;
	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
		rightw--;

	if(temp == SPACE)
	{
		temp = peek(0,2);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			rightw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			rightw--;

		if(temp == SPACE)
		{
			temp = peek(0,3);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				rightw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				rightw--;

			temp = peek(1,2);
			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
				rightw++;
			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
				rightw--;
		}

		temp = peek(1,1);
		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
			rightw++;
		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
			rightw--;
	}
	
	temp = peek(1,0);

	if((leftw)||(rightw)||(forwardw))	
	{
		// forward > left & right
		if((forwardw > leftw)&&(forwardw > rightw))
	        	if((forwardw > 0)&&(temp == SPACE))
        	        	return FORWARD;
	                else 
        	        	if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
        				return bugs->search[search];
        	        	else
	        	        	return getrandom(LEFT,RIGHT);

		// left > forward & right
		if((leftw > rightw)&&(leftw > forwardw))
	        	if(leftw > 0)
        	        	return LEFT;
	                else if(temp == SPACE)
        	        	if((bugs->search[search] == RIGHT)||(bugs->search[search] == FORWARD))
        	        		return bugs->search[search];
				else
	        	        	return getrandom(RIGHT, FORWARD);
			else
				return RIGHT;

		// right > left & forward
		if((rightw > leftw)&&(rightw > forwardw))
	        	if(rightw > 0)
        	        	return RIGHT;
			else if (temp == SPACE)
				if((bugs->search[search] == LEFT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return (getrandom(0,1) ? LEFT : FORWARD);
			else 
				return LEFT;
			
		// left & right > forward
		if((leftw == rightw)&&(rightw > forwardw))
	        	if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
	        		return bugs->search[search];
	        	else
	        		return getrandom(LEFT,RIGHT);

		// forward & right > left
		if((forwardw == rightw)&&(rightw > leftw))
                	if(temp == SPACE)
				if((bugs->search[search] == RIGHT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return getrandom(RIGHT,FORWARD);
			else
				return RIGHT;
			
		// forward & left > right
		if((forwardw == leftw)&&(leftw > rightw))
                	if(temp == SPACE)
				if((bugs->search[search] == LEFT)||(bugs->search[search] == FORWARD))
					return bugs->search[search];
				else
					return (getrandom(0,1) ? LEFT : FORWARD);
			else
				return LEFT;

		// all equil
        	if(temp == SPACE)
        		if(bugs->search[search] == WAIT)
        			return getrandom(LEFT, FORWARD);
        		else
        			return bugs->search[search];
		else
			if((bugs->search[search] == LEFT)||(bugs->search[search] == RIGHT))
				return bugs->search[search];
			else
				return getrandom(LEFT, RIGHT);
	}

	// default din't see anything good ...
	if((temp != SPACE)&&(bugs->search[search] == FORWARD))
		return getrandom(WAIT, RIGHT);

	return bugs->search[search];
}

char peek(int fw, int lr)
{
	int val;
	char temp[3];
	
	switch(bugs->vector)
	{
		case 0:
			val = mvwinnstr(world_pad,(bugs->ypos + world_row - fw) % world_row,(bugs->xpos + world_col + lr) % world_col,temp,1);
			break;
		case 1:
			val = mvwinnstr(world_pad,(bugs->ypos + world_row + lr) % world_row,(bugs->xpos + world_col + fw) % world_col,temp,1);
			break;
		case 2:
			val = mvwinnstr(world_pad,(bugs->ypos + world_row + fw) % world_row,(bugs->xpos + world_col - lr) % world_col,temp,1);
			break;
		case 3:
			val = mvwinnstr(world_pad,(bugs->ypos + world_row - lr) % world_row,(bugs->xpos + world_col - fw) % world_col,temp,1);
			break;
		default:
			fprintf(stderr,"default in peek bugs->vector is bad\n");
			break;   
	}
	return temp[0];
}
